@@ -27,10 +27,10 @@ int main(int argc, char *argv[])
 	KLocalizedString::setApplicationDomain("blinken");
 
 	QApplication app(argc, argv);
-	KAboutData about("blinken", i18n("Blinken"), "0.4", i18n("A memory enhancement game"), KAboutLicense::GPL, i18n("© 2005-2007 Albert Astals Cid\n© 2005-2007 Danny Allen"));
-	about.addAuthor(i18n("Albert Astals Cid"), i18n("Coding"), "aacid@kde.org");
-	about.addAuthor(i18n("Danny Allen"), i18n("Design, Graphics and Sounds"), "danny@dannyallen.co.uk");
-	about.addCredit(i18n("Steve Jordi"), i18n("GPL'ed his 'Steve' font so that we could use it"), "steve@sjordi.com");
+	KAboutData about(QStringLiteral("blinken"), i18n("Blinken"), QStringLiteral("0.4"), i18n("A memory enhancement game"), KAboutLicense::GPL, i18n("© 2005-2007 Albert Astals Cid\n© 2005-2007 Danny Allen"));
+	about.addAuthor(i18n("Albert Astals Cid"), i18n("Coding"), QStringLiteral("aacid@kde.org"));
+	about.addAuthor(i18n("Danny Allen"), i18n("Design, Graphics and Sounds"), QStringLiteral("danny@dannyallen.co.uk"));
+	about.addCredit(i18n("Steve Jordi"), i18n("GPL'ed his 'Steve' font so that we could use it"), QStringLiteral("steve@sjordi.com"));
 
 	KAboutData::setApplicationData(about);
 
@@ -48,11 +48,11 @@ int main(int argc, char *argv[])
 
 	app.setWindowIcon(QIcon::fromTheme(QLatin1String("blinken")));
 
-	QFont f("Steve", 12, QFont::Normal, true);
+ 	QFont f(QStringLiteral("Steve"), 12, QFont::Normal, true);
 	// Works with Steve may need some tweaking to work with other fonts
 	if (!QFontInfo(f).exactMatch())
 	{
-		QFontDatabase::addApplicationFont(QStandardPaths::locate(QStandardPaths::DataLocation, "fonts/steve.ttf"));
+		QFontDatabase::addApplicationFont(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("fonts/steve.ttf")));
 	}
 	KDBusService service;
 	new blinken();
